Crate tiff_tags

Crate tiff_tags 

Functions

get_id
Given the exact name of a tag, return either its u16 ID or None if it is not registered. Note that this function will return None if multiple tags are registered, as this is technically not against the spec. However, no duplicates tags currently are registered according to the source used.
get_name
Given a u16 id number, return either its name or None if the tag is not registered. Note that this function will return None if multiple tags are registered, as this is technically not against the spec. However, no duplicates tags currently are registered according to the source used.